==> benchling_api_client-2.0.36-py3-none-any.whl: benchling_api_client/api/legacy_workflows/list_legacy_workflow_stage_runs.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.legacy_workflow_stage_run_list import LegacyWorkflowStageRunList
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    stage_id: str,
) -> Dict[str, Any]:
    url = "{}/legacy-workflow-stages/{stage_id}/workflow-stage-runs".format(
        client.base_url, stage_id=stage_id
    )

    headers: Dict[str, Any] = client.httpx_client.headers
    headers.update(client.get_headers())

    cookies: Dict[str, Any] = client.httpx_client.cookies
    cookies.update(client.get_cookies())

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[LegacyWorkflowStageRunList]:
    if response.status_code == 200:
        response_200 = LegacyWorkflowStageRunList.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[LegacyWorkflowStageRunList]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    stage_id: str,
) -> Response[LegacyWorkflowStageRunList]:
    kwargs = _get_kwargs(
        client=client,
        stage_id=stage_id,
    )

    response = client.httpx_client.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    stage_id: str,
) -> Optional[LegacyWorkflowStageRunList]:
    """ List legacy workflow stage runs """

    return sync_detailed(
        client=client,
        stage_id=stage_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    stage_id: str,
) -> Response[LegacyWorkflowStageRunList]:
    kwargs = _get_kwargs(
        client=client,
        stage_id=stage_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    stage_id: str,
) -> Optional[LegacyWorkflowStageRunList]:
    """ List legacy workflow stage runs """

    return (
        await asyncio_detailed(
            client=client,
            stage_id=stage_id,
        )
    ).parsed

==> benchling_api_client-2.0.343-py3-none-any.whl: benchling_api_client/api/legacy_workflows/list_legacy_workflow_stage_runs.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.legacy_workflow_stage_run_list import LegacyWorkflowStageRunList
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    stage_id: str,
) -> Dict[str, Any]:
    url = "{}/legacy-workflow-stages/{stage_id}/workflow-stage-runs".format(
        client.base_url, stage_id=stage_id
    )

    headers: Dict[str, Any] = client.httpx_client.headers
    headers.update(client.get_headers())

    cookies: Dict[str, Any] = client.httpx_client.cookies
    cookies.update(client.get_cookies())

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[LegacyWorkflowStageRunList]:
    if response.status_code == 200:
        response_200 = LegacyWorkflowStageRunList.from_dict(response.json(), strict=False)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[LegacyWorkflowStageRunList]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    stage_id: str,
) -> Response[LegacyWorkflowStageRunList]:
    kwargs = _get_kwargs(
        client=client,
        stage_id=stage_id,
    )

    response = client.httpx_client.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    stage_id: str,
) -> Optional[LegacyWorkflowStageRunList]:
    """ List legacy workflow stage runs """

    return sync_detailed(
        client=client,
        stage_id=stage_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    stage_id: str,
) -> Response[LegacyWorkflowStageRunList]:
    kwargs = _get_kwargs(
        client=client,
        stage_id=stage_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    stage_id: str,
) -> Optional[LegacyWorkflowStageRunList]:
    """ List legacy workflow stage runs """

    return (
        await asyncio_detailed(
            client=client,
            stage_id=stage_id,
        )
    ).parsed
